import 'dart:convert';

import 'package:encrypt/encrypt.dart';

import '../constants.dart';

class AESAlgorithm {
  /// The AES init vector generated randomly with [Constants.CRYPTO_IV_LENGTH] length
  final IV _iv = IV.fromSecureRandom(Constants.CRYPTO_IV_LENGTH);

  Encrypter _aes;

  IV get initVector {
    return _iv;
  }

  AESAlgorithm(secretKey) {
    _aes = Encrypter(
      AES(
        Key.fromBase64(
          secretKey,
        ),
        mode: AESMode.cbc,
      ),
    );
  }

  /// Encrypts [plainText] with AES algorithm
  ///
  /// Returns encrypted [String] encoded to [base64]
  String encrypt(String plainText) {
    return _aes.encrypt(plainText, iv: this._iv).base64;
  }

  ///Decrypts [encryptedText] with AES algorithm
  ///
  /// Returns decrypted [String]
  String decrypt(String encryptedText) {
    return utf8.decode(base64Decode(
        _aes.decrypt(Encrypted.fromBase64(encryptedText), iv: this._iv)));
  }
}
